import { world, system, EquipmentSlot, EntityComponentTypes } from "@minecraft/server"

system.beforeEvents.watchdogTerminate.subscribe(eventData => {
    console.error("watchdog = " + eventData.terminateReason +
        " trying to cancel crash")
    eventData.cancel = true
})

const blocks15level = [
    "nk:campfire",
    "nk:glowstone",
    "nk:lantern",
    "nk:sea_lantern",
    "nk:lava_bucket",
    "nk:ochre_froglight",
    "nk:pearlescent_froglight",
    "nk:verdant_froglight",
    "nk:torch",
    "minecraft:campfire",
    "minecraft:glowstone",
    "minecraft:lantern",
    "minecraft:sea_lantern",
    "minecraft:lava_bucket",
    "minecraft:ochre_froglight",
    "minecraft:pearlescent_froglight",
    "minecraft:verdant_froglight",
    "minecraft:torch"
]
const blocks7level = [
    "nk:beacon",
    "nk:soul_campfire",
    "nk:soul_lantern",
    "nk:glow_berries",
    "nk:soul_torch",
    "nk:redstone_torch",
    "nk:magma",
    "nk:glow_item_frame",
    "nk:glow_ink_sac",
    "nk:crying_obsidian",
    "minecraft:beacon",
    "minecraft:soul_campfire",
    "minecraft:soul_lantern",
    "minecraft:glow_berries",
    "minecraft:soul_torch",
    "minecraft:redstone_torch",
    "minecraft:magma",
    "minecraft:glow_frame",
    "minecraft:glow_ink_sac",
    "minecraft:crying_obsidian"
]

system.runInterval(() => {
    const players = world.getAllPlayers()
    players.forEach(player => {
        const loc1 = player.getHeadLocation()
        player.runCommand(`fill ${loc1.x - 5} ${loc1.y - 5} ${loc1.z - 5} ${loc1.x + 5} ${loc1.y + 5} ${loc1.z + 5} air [] replace light_block`)
        if (player.isOnGround || player.isJumping) {
            blocks15level.forEach(block => {
                light_around(player, block, 15)
            })

            blocks7level.forEach(block => {
                light_around(player, block, 8)
            })
        }
    })

}, 10)

function light_around(player, light_block, light_level) {
    const off_hand = player.getComponent(EntityComponentTypes.Equippable).getEquipmentSlot(EquipmentSlot.Offhand).getItem()
    const main_hand = player.getComponent(EntityComponentTypes.Equippable).getEquipmentSlot(EquipmentSlot.Mainhand).getItem()

    if ((off_hand && off_hand.typeId == light_block) || (main_hand && main_hand.typeId == light_block)) {
        const loc = player.getHeadLocation()
        if (world.getDimension(player.dimension.id).getBlock(loc).typeId == "minecraft:air")
            player.runCommand(`setblock ${loc.x} ${loc.y} ${loc.z} light_block ["block_light_level"=${light_level}]`)
    } else {
        return;
    }
}
